@@ -1305,9 +1305,9 @@ class DescribeTopSpaceSchemaTimeSeriesRequest(AbstractModel):
         :type Limit: int
         :param SortBy: 筛选Top库所用的排序字段，可选字段包含DataLength、IndexLength、TotalLength、DataFree、FragRatio、TableRows、PhysicalFileSize（仅云数据库 MySQL实例支持），云数据库 MySQL实例默认为 PhysicalFileSize，其他产品实例默认为TotalLength。
         :type SortBy: str
-        :param StartDate: 开始日期，最早为当日的前第29天，默认为截止日期的前第6天。
+        :param StartDate: 开始日期，如“2021-01-01”，最早为当日的前第29天，默认为截止日期的前第6天。
         :type StartDate: str
-        :param EndDate: 截止日期，最早为当日的前第29天，默认为当日。
+        :param EndDate: 截止日期，如“2021-01-01”，最早为当日的前第29天，默认为当日。
         :type EndDate: str
         :param Product: 服务产品类型，支持值包括： "mysql" - 云数据库 MySQL， "cynosdb" - 云数据库 CynosDB  for MySQL，默认为"mysql"。
         :type Product: str
@@ -1427,9 +1427,9 @@ class DescribeTopSpaceTableTimeSeriesRequest(AbstractModel):
         :type Limit: int
         :param SortBy: 筛选Top表所用的排序字段，可选字段包含DataLength、IndexLength、TotalLength、DataFree、FragRatio、TableRows、PhysicalFileSize，默认为 PhysicalFileSize。
         :type SortBy: str
-        :param StartDate: 开始日期，最早为当日的前第29天，默认为截止日期的前第6天。
+        :param StartDate: 开始日期，如“2021-01-01”，最早为当日的前第29天，默认为截止日期的前第6天。
         :type StartDate: str
-        :param EndDate: 截止日期，最早为当日的前第29天，默认为当日。
+        :param EndDate: 截止日期，如“2021-01-01”，最早为当日的前第29天，默认为当日。
         :type EndDate: str
         :param Product: 服务产品类型，支持值包括： "mysql" - 云数据库 MySQL， "cynosdb" - 云数据库 CynosDB  for MySQL，默认为"mysql"。
         :type Product: str
